Daemon rucio-minos-temporary-expiration
***************************************
.. argparse::
   :filename: bin/rucio-minos-temporary-expiration
   :func: get_parser
   :prog: rucio-minos-temporary-expiration
